@@ -3,6 +3,7 @@ import multiprocessing
 import os.path
 from concurrent.futures import Executor
 from typing import Callable, Optional
+from warnings import warn
 
 
 def check_oversubscribe(oversubscribe: bool) -> None:
@@ -145,10 +146,10 @@ def check_hostname_localhost(hostname_localhost: Optional[bool]) -> None:
         )
 
 
-def check_flux_executor_pmi_mode(flux_executor_pmi_mode: Optional[str]) -> None:
-    if flux_executor_pmi_mode is not None:
+def check_pmi_mode(pmi_mode: Optional[str]) -> None:
+    if pmi_mode is not None:
         raise ValueError(
-            "The option to specify the flux pmi mode is not available with the pysqa based backend."
+            "The option to specify the pmi mode is not available on a local workstation, it requires SLURM or flux."
         )
 
 
@@ -190,7 +191,13 @@ def validate_number_of_cores(
             "Block allocation requires a fixed set of computational resources. Neither max_cores nor max_workers are defined."
         )
     else:
-        return multiprocessing.cpu_count()
+        max_workers = multiprocessing.cpu_count()
+        warn(
+            "max_workers parameter is not set, set default based on CPU count to: max_workers="
+            + str(max_workers),
+            stacklevel=2,
+        )
+        return max_workers
 
 
 def check_file_exists(file_name: Optional[str]):
