@@ -28,7 +28,7 @@ def cloudpickle_register(ind: int = 2):
         pass
 
 
-def serialize_funct_h5(
+def serialize_funct(
     fn: Callable,
     fn_args: Optional[list] = None,
     fn_kwargs: Optional[dict] = None,
@@ -42,16 +42,16 @@ def serialize_funct_h5(
         fn (Callable): The function to be serialized.
         fn_args (list): The arguments of the function.
         fn_kwargs (dict): The keyword arguments of the function.
-        resource_dict (dict): resource dictionary, which defines the resources used for the execution of the function.
-                              Example resource dictionary: {
-                                  cores: 1,
-                                  threads_per_core: 1,
-                                  gpus_per_worker: 0,
-                                  oversubscribe: False,
-                                  cwd: None,
-                                  executor: None,
-                                  hostname_localhost: False,
-                              }
+        resource_dict (dict): A dictionary of resources required by the task. With the following keys:
+                              - cores (int): number of MPI cores to be used for each function call
+                              - threads_per_core (int): number of OpenMP threads to be used for each function call
+                              - gpus_per_core (int): number of GPUs per worker - defaults to 0
+                              - cwd (str/None): current working directory where the parallel python task is executed
+                              - openmpi_oversubscribe (bool): adds the `--oversubscribe` command line flag (OpenMPI and
+                                                              SLURM only) - default False
+                              - slurm_cmd_args (list): Additional command line arguments for the srun call (SLURM only)
+                              - error_log_file (str): Name of the error log file to use for storing exceptions raised
+                                                      by the Python functions submitted to the Executor.
         cache_key (str, optional): By default the cache_key is generated based on the function hash, this can be
                                    overwritten by setting the cache_key.
 
